<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class HomeMultiBlog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'home-multi-blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home Multi - Blog Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-multi' ];
	}

	public function get_keywords() {
		return [ 'Blog', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_blog',
			[
				'label' => esc_html__( 'Home Multi Blog', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'bg_select',
			[
				'label'     => esc_html__( 'Backgroud Select', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'dynamic' => [ 'active' => true ],
				'options'   => [
					'1'  => esc_html__( 'Light', 'bdevs-elementor' ),
					'2'  => esc_html__( 'Dark', 'bdevs-elementor' ),
				],
				'default'   => '1',
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
            'post_number',
            [
                'label'       => __( 'Post Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Number', 'bdevs-elementor' ),
                'default'     => __( '2', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );


		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_sub_heading',
			[
				'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<?php if( wp_kses_post($settings['bg_select']) == '1'): ?>
		<div class="nopixel-blog section-padding bg-color">
		<?php elseif( wp_kses_post($settings['bg_select']) == '2'): ?>
		<div class="nopixel-blog dark-blog section-padding">
		<?php endif; ?>

		<div class="container">

			<div class="row mb-30">

				<div class="section-head col-md-12">

					<?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
					<div class="section-subtitle"><?php echo wp_kses_post($settings['sub_heading']); ?></div>
					<?php endif; ?>

					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
					<div class="section-title"><?php echo wp_kses_post($settings['heading']); ?>
					</div>
					<?php endif; ?>

				</div>

			</div>

			<?php 
				$order = $settings['post_order'];
				$post_number = $settings['post_number'];
				$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order));
				$i = 0;
				while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
					$i++;
					?>

			<?php if ($i % 2 == 0) { ?>

			<div class="row mb-30">

				<div class="col-md-6 animate-box" data-animate-effect="fadeInLeft">

					<div class="img left">

						<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>

					</div>

				</div>

				<div class="col-md-6 valign animate-box" data-animate-effect="fadeInRight">

					<div class="content">

						<div class="cont">

							<div class="info"><div> <?php the_author_posts_link(); ?> <p class="distance">/</p> <?php the_time(get_option( 'date_format'));?></div></div>

							<h5><a href="<?php the_permalink();?>"><?php the_title();?></a></h5>

							<p class="text-content"><?php if(isset($nopixel_redux_demo['blog_excerpt_2'])){?>

								<?php echo esc_attr(nopixel_excerpt_2($nopixel_redux_demo['blog_excerpt_2'])); ?>

							<?php }else{?>

								<?php echo esc_attr(nopixel_excerpt_2(25));}?></p> 

							<a href="<?php the_permalink();?>" class="more" data-splitting=""><span><?php echo esc_html__( 'Read More', 'nopixel' )?></span></a>

						</div>

					</div>

				</div>

			</div>

		<?php } else { ?>

			<div class="row mb-30">

				<div class="col-md-6 valign animate-box" data-animate-effect="fadeInRight">

					<div class="content">

						<div class="cont">

							<div class="info"><div> <?php the_author_posts_link(); ?> <p class="distance">/</p> <?php the_time(get_option( 'date_format'));?></div></div>

							<h5><a href="<?php the_permalink();?>"><?php the_title();?></a></h5>

							<p class="text-content"><?php if(isset($nopixel_redux_demo['blog_excerpt_2'])){?>

								<?php echo esc_attr(nopixel_excerpt_2($nopixel_redux_demo['blog_excerpt_2'])); ?>

							<?php }else{?>

								<?php echo esc_attr(nopixel_excerpt_2(25)); }?></p> 

							<a href="<?php the_permalink();?>" class="more" data-splitting=""><span><?php echo esc_html__( 'Read More', 'nopixel' )?></span></a>

						</div>

					</div>

				</div>

				<div class="col-md-6 animate-box" data-animate-effect="fadeInLeft">

					<div class="img left">

						<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>

					</div>

				</div>

			</div>

		<?php } ?>

			<?php endwhile; ?>

		</div>

	</div>

	<!-- hr -->

	<hr class="line-vr-section animate-box" data-animate-effect="fadeInUp">

	<?php
	}

}
