<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class PagesFAQ extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pages-faq';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pages - FAQ Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'pages' ];
	}

	public function get_keywords() {
		return [ 'Faq', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_faq',
			[
				'label' => esc_html__( 'FAQ Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'FAQ Items (Left Column)', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
				        'name'        => 'faq_select',
				        'label'     => esc_html__( 'FAQ Select', 'bdevs-elementor' ),
				        'type'      => Controls_Manager::SELECT,
				        'dynamic' => [ 'active' => true ],
				        'options'   => [
				        '1'  => esc_html__( 'Active', 'bdevs-elementor' ),
				        '2'  => esc_html__( 'Inactive', 'bdevs-elementor' ),
				        ],
				        'default'   => '2',
				    ],			
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->add_control(
			'tabs_2',
			[
				'label' => esc_html__( 'FAQ Items (Right Column)', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
				        'name'        => 'faq_select',
				        'label'     => esc_html__( 'FAQ Select', 'bdevs-elementor' ),
				        'type'      => Controls_Manager::SELECT,
				        'dynamic' => [ 'active' => true ],
				        'options'   => [
				        '1'  => esc_html__( 'Active', 'bdevs-elementor' ),
				        '2'  => esc_html__( 'Inactive', 'bdevs-elementor' ),
				        ],
				        'default'   => '2',
				    ],			
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<div class="section-padding">
			<div class="container">
				<div class="row">
					<div class="col-md-6 animate-box" data-animate-effect="fadeInUp">
						<ul class="accordion-box clearfix">
							<?php foreach ( $settings['tabs'] as $item ) : ?>
								<?php if( wp_kses_post($item['faq_select']) == '1'): ?>
									<li class="accordion block active-block">
										<div class="acc-btn active">
											<?php if ( '' !== $item['tab_title'] ) : ?>
											<?php echo wp_kses_post($item['tab_title']); ?>
											<?php endif; ?>
										</div>
										<div class="acc-content current">
											<div class="content">
												<?php if ( '' !== $item['tab_subtitle'] ) : ?>
												<div class="text"><?php echo wp_kses_post($item['tab_subtitle']); ?></div>
												<?php endif; ?>
											</div>
										</div>
									</li>
									<?php elseif( wp_kses_post($item['faq_select']) == '2'): ?>
									<li class="accordion block">
										<div class="acc-btn">
											<?php if ( '' !== $item['tab_title'] ) : ?>
												<?php echo wp_kses_post($item['tab_title']); ?>
											<?php endif; ?>
										</div>
										<div class="acc-content">
											<div class="content">
												<?php if ( '' !== $item['tab_subtitle'] ) : ?>
													<div class="text"><?php echo wp_kses_post($item['tab_subtitle']); ?></div>
												<?php endif; ?>
											</div>
										</div>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						</ul>
					</div>
					<div class="col-md-6 animate-box" data-animate-effect="fadeInUp">
						<ul class="accordion-box clearfix">
							<?php foreach ( $settings['tabs_2'] as $item ) : ?>
								<?php if( wp_kses_post($item['faq_select']) == '1'): ?>
									<li class="accordion block active-block">
										<div class="acc-btn active">
											<?php if ( '' !== $item['tab_title'] ) : ?>
											<?php echo wp_kses_post($item['tab_title']); ?>
											<?php endif; ?>
										</div>
										<div class="acc-content current">
											<div class="content">
												<?php if ( '' !== $item['tab_subtitle'] ) : ?>
												<div class="text"><?php echo wp_kses_post($item['tab_subtitle']); ?></div>
												<?php endif; ?>
											</div>
										</div>
									</li>
									<?php elseif( wp_kses_post($item['faq_select']) == '2'): ?>
									<li class="accordion block">
										<div class="acc-btn">
											<?php if ( '' !== $item['tab_title'] ) : ?>
												<?php echo wp_kses_post($item['tab_title']); ?>
											<?php endif; ?>
										</div>
										<div class="acc-content">
											<div class="content">
												<?php if ( '' !== $item['tab_subtitle'] ) : ?>
													<div class="text"><?php echo wp_kses_post($item['tab_subtitle']); ?></div>
												<?php endif; ?>
											</div>
										</div>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						</ul>
					</div>
				</div>
			</div>
		</div>
	<!-- hr -->
	<hr class="line-vr-section animate-box" data-animate-effect="fadeInUp">

	<?php
	}

}
